@@ -14,7 +14,10 @@ This file is for clutter based gui and it handles config file reading
 #include "../../meam/jammo-editing-track.h"
 #include "../configure.h"
 #include "song.h"
+#include "jammo-collaboration-pair-composition.h"
 
+JammoCollaborationPairComposition* chum_get_pair_composition();
+void chum_set_pair_composition(JammoCollaborationPairComposition* pc);
 
 jammo_song* chum_get_current_song();
 void chum_set_current_song(jammo_song* song);
