@@ -11,5 +11,5 @@ static void end_jammo(JammoMentor* mentor, const gchar* speech, gboolean interru
 }
 
 void quitconfirmation_quit_confirmed(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "quit_byebye.ogg", end_jammo, NULL);
+	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "quit_byebye.spx", end_jammo, NULL);
 }
