@@ -157,8 +157,8 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 	g_return_if_fail(ofp != NULL);
 
 	fprintf(ofp,"{\n");
-	fprintf(ofp,"\"fullpath\" : \"%s\"\n",(chum_get_current_song())->fullpath);
-	fprintf(ofp,"\"recorded_filename\" : \"%s\"\n",filename);
+	fprintf(ofp,"\"fullpath\" : \"%s\",\n",(chum_get_current_song())->fullpath);
+	fprintf(ofp,"\"recorded_filename\" : \"%s\",\n",filename);
 	fprintf(ofp,"\"language\" : \"%s\"\n",chum_get_selected_language());
 	fprintf(ofp,"}\n");
 	fclose(ofp);
