@@ -426,12 +426,12 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 		gchar *filename;
 		int fd;
-		filename = g_strdup_printf("%s/comping%s.spx", song->fullpath,song->language);
+		filename = g_strdup_printf("%s/comping%s.ogg", song->fullpath,song->language);
 		fd = open(filename,O_RDONLY);
 		if (fd == -1) //File not found
 			{  //no track for this language,. use  common comping. THIS IS ERROR case. malfuncted savefile!
 			g_free(filename);
-			filename = g_strdup_printf("%s/comping.spx", song->fullpath); //try without language postfix
+			filename = g_strdup_printf("%s/comping.ogg", song->fullpath); //try without language postfix
 			}
 		printf("looking for file '%s' for comping_track\n",filename);
 
