@@ -53,8 +53,8 @@ static void jammo_cursor_dispose(GObject* object) {
 
 	cursor = JAMMO_CURSOR(object);
 
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(cursor->priv->sequencer);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(cursor->priv->texture);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(cursor->priv->sequencer);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(cursor->priv->texture);
 
 	if (cursor->priv->sequencer_started_handler_id) {
 		g_signal_handler_disconnect(cursor->priv->sequencer, cursor->priv->sequencer_started_handler_id);
