@@ -12,7 +12,7 @@
 #include "../meam/jammo-sample.h"
 #include <time.h>
 
-G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON);
+G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON)
 
 enum {
 	PROP_0,
@@ -338,48 +338,98 @@ static void jammo_mentor_init(JammoMentor* mentor) {
 	mentors = g_list_append(mentors, mentor);
 }
 
+static const gchar* find_characters(const gchar* string, const gchar* characters) {
+	const gchar* found = NULL;
+	const gchar* c;
+	
+	while (!found && *string) {
+		for (c = characters; *c; c++) {
+			if (*string == *c) {
+				found = string;
+				break;
+			}
+		}
+		string++;
+	}
+	
+	return found;
+}
+
+static const gchar* find_characters_inverse(const gchar* string, const gchar* characters) {
+	const gchar* found = NULL;
+	const gchar* c;
+	
+	while (*string) {
+		for (c = characters; *c; c++) {
+			if (*string == *c) {
+				break;
+			}
+		}
+		if (!*c) {
+			found = string;
+			break;
+		}
+		string++;
+	}
+	
+	return found;
+}
+
+static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMentorSpokenCallback callback, const gchar* speech, gpointer user_data);
+
 static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	TangleVault* vault;
 	JammoMentor* mentor;
+	const gchar* next_speech;
 	JammoMentorSpokenCallback callback;
 	const gchar* speech;
 	gpointer data;
 	
 	vault = TANGLE_VAULT(user_data);
-	tangle_vault_get(vault, 4, JAMMO_TYPE_MENTOR, &mentor, G_TYPE_POINTER, &callback, G_TYPE_STRING, &speech, G_TYPE_POINTER, &data);
+	tangle_vault_get(vault, 5, JAMMO_TYPE_MENTOR, &mentor, G_TYPE_STRING, &next_speech, G_TYPE_POINTER, &callback, G_TYPE_STRING, &speech, G_TYPE_POINTER, &data);
 	
 	g_object_unref(mentor->priv->active_sample);
 	mentor->priv->active_sample = NULL;
 
-	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+	if (next_speech) {
+		real_speak(mentor, next_speech, callback, speech, data);
+	} else {
 
-	set_idle_timeout(mentor, TRUE);
-	
-	if (callback) {
-		callback(mentor, speech, mentor->priv->interrupted, data);
+		tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+
+		set_idle_timeout(mentor, TRUE);
+
+		if (callback) {
+			callback(mentor, speech, mentor->priv->interrupted, data);
+		}
+
+		mentor->priv->interrupted = FALSE;
+
+		/* TODO: g_free(speech); ? */
 	}
-
-	mentor->priv->interrupted = FALSE;
-	
-	/* TODO: g_free(speech); ? */
 }
 
-static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {
+#define WHITE_SPACES " \t\n\r"
+
+static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMentorSpokenCallback callback, const gchar* speech, gpointer user_data) {
+	const gchar* space;
+	gchar* current_speech;
 	gchar* localized_speech;
 	gchar* filename;
 	TangleVault* vault;
 	
-	set_idle_timeout(mentor, FALSE);
-	tangle_actor_show(TANGLE_ACTOR(mentor));
-	
-	if (mentor->priv->active_sample) {
-		jammo_sample_stop(mentor->priv->active_sample);
+	if ((space = find_characters(next_speech, WHITE_SPACES))) {
+		current_speech = g_strndup(next_speech, space - next_speech);
+		next_speech = find_characters_inverse(space, WHITE_SPACES);
+	} else {
+		current_speech = g_strdup(next_speech);
+		next_speech = NULL;
 	}
 	
-	if (speech[0] == '/' || !mentor->priv->language) {
-		localized_speech = g_strdup(speech);
+	if (current_speech[0] == '/' || !mentor->priv->language) {
+		localized_speech = g_strdup(current_speech);
 	} else {
-		localized_speech = g_strconcat(mentor->priv->language, "/", speech, NULL);
+		localized_speech = g_strconcat(mentor->priv->language, "/", current_speech, NULL);
 	}
 	if ((filename = tangle_actor_lookup_filename(TANGLE_ACTOR(mentor), localized_speech))) {
 		mentor->priv->active_sample = jammo_sample_new_from_file(filename);
@@ -387,14 +437,29 @@ static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight,
 	} else {
 		mentor->priv->active_sample = jammo_sample_new_from_file(localized_speech);
 	}
+
+printf("%s * %s * %s * %s\n", current_speech, localized_speech, speech, next_speech);
+
 	g_free(localized_speech);
+	g_free(current_speech);
 	
-	vault = tangle_vault_new(4, JAMMO_TYPE_MENTOR, mentor, G_TYPE_POINTER, callback, G_TYPE_STRING, speech, G_TYPE_POINTER, user_data);
+	vault = tangle_vault_new(5, JAMMO_TYPE_MENTOR, mentor, G_TYPE_STRING, next_speech, G_TYPE_POINTER, callback, G_TYPE_STRING, speech, G_TYPE_POINTER, user_data);
 	tangle_signal_connect_vault(mentor->priv->active_sample, "stopped", G_CALLBACK(on_sample_stopped), vault);
+
+	jammo_sample_play(mentor->priv->active_sample);
+}
+
+static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {	
+	set_idle_timeout(mentor, FALSE);
+	tangle_actor_show(TANGLE_ACTOR(mentor));
+	
+	if (mentor->priv->active_sample) {
+		jammo_sample_stop(mentor->priv->active_sample);
+	}
+
+	real_speak(mentor, speech, callback, speech, user_data);
 	
 	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "squint-x", offset_x, "squint-y", offset_y, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
-		
-	jammo_sample_play(mentor->priv->active_sample);
 }
 
 static gboolean on_stage_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
