@@ -20,6 +20,7 @@ enum {
 	PROP_SAMPLE_FILENAME,
 	PROP_SAMPLE,
 	PROP_SAMPLE_TYPE,
+	PROP_LOOP_ID,
 	PROP_TEXT
 };
 
@@ -32,6 +33,7 @@ struct _JammoSampleButtonPrivate {
 	gchar* image_filename;
 	JammoSample* sample;
 	JammoSampleType sample_type;
+	gint loop_id;
 };
 
 static const GEnumValue sample_type_values[] = {
@@ -80,7 +82,7 @@ ClutterActor* jammo_sample_button_new_with_type_from_files(JammoSampleType sampl
 
 ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button) {
 
-	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, NULL));
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, "loop-id", sample_button->priv->loop_id, NULL));
 }
 
 const gchar* jammo_sample_button_get_image_filename(JammoSampleButton* sample_button) {
@@ -98,6 +100,16 @@ JammoSample* jammo_sample_button_get_sample(JammoSampleButton* sample_button) {
 	return sample_button->priv->sample;
 }
 
+gint jammo_sample_button_get_loop_id(JammoSampleButton* sample_button) {
+
+	return sample_button->priv->loop_id;
+}
+
+void jammo_sample_button_set_loop_id(JammoSampleButton* sample_button, gint loop_id) {
+
+	sample_button->priv->loop_id = loop_id;
+}
+
 void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, const gchar* image_filename) {
 	ClutterActor* texture;
 	
@@ -254,6 +266,9 @@ static void jammo_sample_button_set_property(GObject* object, guint prop_id, con
 		case PROP_SAMPLE_TYPE:
 			sample_button->priv->sample_type = g_value_get_enum(value);
 			break;
+		case PROP_LOOP_ID:
+			sample_button->priv->loop_id = g_value_get_int(value);
+			break;
 		case PROP_TEXT:
 			jammo_sample_button_set_text(sample_button, g_value_get_string(value));
 			break;
@@ -281,6 +296,9 @@ static void jammo_sample_button_get_property(GObject* object, guint prop_id, GVa
 		case PROP_SAMPLE_TYPE:
 			g_value_set_enum(value, sample_button->priv->sample_type);
 			break;
+		case PROP_LOOP_ID:
+			g_value_set_int(value, sample_button->priv->loop_id);
+			break;
 		case PROP_TEXT:
 			g_value_set_string(value, jammo_sample_button_get_text(sample_button));
 			break;
@@ -348,6 +366,20 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 	                                "The type of the sample (not used internally)",
 	                                JAMMO_TYPE_SAMPLE_TYPE, JAMMO_SAMPLE_UNTYPED,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+
+	/**
+	 * JammoSampleButton:loop_id:
+	 *
+	 * The loop_id: if two sample_buttons have same image and same audio, they have same loop_id.
+	 * (sample_button in another themepack can have same loop_id)
+	 */
+	g_object_class_install_property(gobject_class, PROP_LOOP_ID,
+	                                g_param_spec_int("loop-id",
+	                                "Loop ID",
+	                                "Loop ID",
+	                                0, G_MAXINT, 0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+
 	/**
 	 * JammoSampleButton:text:
 	 *
