@@ -293,8 +293,13 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 		tangle_widget_add(widget, copy_of_sample_button, NULL);
 
 		clutter_actor_animate(copy_of_sample_button, CLUTTER_EASE_OUT_CUBIC, 300, "x", slot * track_view->priv->real_slot_width, "y", 0.0, NULL);
-
-		gems_add_new_sample_to_track(12, slot); //TODO loop_id
+/*
+		if (sample_button==NULL)
+			printf("sample_button is null\n");
+		gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(sample_button));
+		printf("name is '%s'\n",name);
+		if (name)*/
+		gems_add_new_sample_to_track(jammo_sample_button_get_loop_id(sample_button), slot); //loop_id is actors 'name' field
 	}
 	
 	track_view->priv->hilighted_start = track_view->priv->hilighted_end = -1.0;
@@ -677,8 +682,12 @@ static void on_actor_removed(TangleWidget* widget, ClutterActor* actor, gpointer
 	
 	jammo_editing_track_remove_sample(track_view->priv->track, jammo_sample_button_get_sample(sample_button));
 
-	guint slot = clutter_actor_get_x(actor) / track_view->priv->slot_width;
-	gems_remove_sample_from_slot(slot);
+	//If editing is not allowed, this actor was removed by network and should not been informed to gems
+	if (track_view->priv->editing_enabled) {
+		guint slot = clutter_actor_get_x(actor) / track_view->priv->slot_width;
+		gems_remove_sample_from_slot(slot);
+	}
+
 }
 
 static gboolean check_if_overlapping(JammoTrackView* track_view, ClutterActor* sample_button, guint slot_index) {
