@@ -36,6 +36,12 @@ GType jammo_sequencer_get_type(void);
 
 #include "jammo-track.h"
 
+// modes, audio plays audio, file generates a wav file
+enum {
+	SEQUENCER_AUDIO_MODE=1,
+	SEQUENCER_FILE_MODE
+};
+
 JammoSequencer* jammo_sequencer_new(void);
 
 gboolean jammo_sequencer_is_ready(JammoSequencer* sequencer);
@@ -50,5 +56,9 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track);
 
 guint64 jammo_sequencer_get_duration(JammoSequencer* sequencer);
 guint64 jammo_sequencer_get_position(JammoSequencer* sequencer);
+gboolean jammo_sequencer_set_position(JammoSequencer* sequencer, guint64 position);
+
+gint jammo_sequencer_file_mode(JammoSequencer* sequencer, gchar* filename);
+gint jammo_sequencer_audio_mode(JammoSequencer* sequencer);
 
 #endif
